import { __awaiter, __decorate, __metadata } from 'tslib';
import { Injectable, Inject, ɵɵdefineInjectable, ɵɵinject, NgModule } from '@angular/core';
import { DOCUMENT } from '@angular/common';
import { BehaviorSubject, Subject } from 'rxjs';

/**
 * @fileoverview added by tsickle
 * Generated from: lib/interface.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @record
 */
function OneSignalStub() { }
if (false) {
    /** @type {?} */
    OneSignalStub.prototype.init;
    /** @type {?} */
    OneSignalStub.prototype.registerForPushNotifications;
    /** @type {?} */
    OneSignalStub.prototype.getUserId;
    /** @type {?} */
    OneSignalStub.prototype.setSubscription;
    /** @type {?} */
    OneSignalStub.prototype.isPushNotificationsEnabled;
    /** @type {?} */
    OneSignalStub.prototype.isOptedOut;
    /** @type {?} */
    OneSignalStub.prototype.isPushNotificationsSupported;
    /** @type {?} */
    OneSignalStub.prototype.subscriptionChange;
    /** @type {?} */
    OneSignalStub.prototype.push;
    /** @type {?} */
    OneSignalStub.prototype.on;
}
/**
 * initialize OneSignal.
 * @see {\@link https://documentation.onesignal.com/docs/web-push-sdk#section--init-}
 * @abstract
 */
class OneSignalOptions {
}
if (false) {
    /** @type {?} */
    OneSignalOptions.prototype.appId;
    /** @type {?} */
    OneSignalOptions.prototype.autoRegister;
    /** @type {?} */
    OneSignalOptions.prototype.allowLocalhostAsSecureOrigin;
    /* Skipping unhandled member: [prop: string]: any;*/
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/decorators.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
/**
 * @param {?} initProp
 * @return {?}
 */
function ExecIf(initProp) {
    return (/**
     * @param {?} target
     * @param {?} name
     * @param {?} descriptor
     * @return {?}
     */
    (target, name, descriptor) => {
        /** @type {?} */
        const method = descriptor.value;
        descriptor.value = (/**
         * @return {?}
         */
        function () {
            console.log(this, arguments);
            if (this[initProp]) {
                return method.apply(this, arguments);
            }
            return void 0;
        });
    });
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/service/one-signal.service.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
// @dynamic
class OneSignalService {
    /**
     * @param {?} doc
     * @param {?} options
     */
    constructor(doc, options) {
        this.doc = doc;
        this.options = options;
        this.scriptinitalize = false;
        this.scriptURL = 'https://cdn.onesignal.com/sdks/OneSignalSDK.js';
        this.isSupported$ = new BehaviorSubject(false);
        this.isSubscribe$ = new BehaviorSubject(false);
        this.isOptedOut$ = new BehaviorSubject(false);
        this.event$ = new Subject();
        this.isPushNotificationsEnabled$ = new BehaviorSubject(false);
        this.init();
    }
    /**
     * @return {?}
     */
    get isSupported() {
        return this.isSupported$.value;
    }
    /**
     * @return {?}
     */
    get isSubscribe() {
        return this.isSubscribe$.value;
    }
    /**
     * @return {?}
     */
    get isInitialized() {
        return this.scriptinitalize;
    }
    /**
     * @return {?}
     */
    get isOptedOut() {
        return this.isOptedOut$.value;
    }
    /**
     * @return {?}
     */
    get event() {
        return this.event$;
    }
    /**
     * @return {?}
     */
    subscribe() {
        if (this.isSupported) {
            if (this.isOptedOut$.value) {
                OneSignal.setSubscription(true);
            }
            else {
                OneSignal.registerForPushNotifications();
            }
            this.listenForNotification();
        }
    }
    /**
     * call OneSignal.setSubscription(false)
     * @see {\@link https://documentation.onesignal.com/docs/web-push-sdk#section--setsubscription-}
     * @return {?}
     */
    unsubscribe() {
        if (this.isSubscribe) {
            OneSignal.setSubscription(false);
        }
    }
    /**
     * https://documentation.onesignal.com/docs/web-push-sdk#section-loading-sdk-asynchronously
     * \@example
     * ngxOneSignal.push(['sendTag', 'key', 'value', function(tagsSent) {
     *   // Callback called when tags have finished sending
     * }]);
     * // or
     * ngxOneSignal.push(['sendTag', 'key', 'value']).then((tagsSent) => {
     *   // Callback called when tags have finished sending
     * });
     * @param {?} items push(["functionName", param1, param2]);
     * @return {?}
     */
    push(items) {
        if (this.isSupported) {
            return OneSignal.push(items);
        }
        else {
            return Promise.resolve();
        }
    }
    /**
     * @private
     * @return {?}
     */
    init() {
        return __awaiter(this, void 0, void 0, function* () {
            try {
                if (!this.scriptinitalize) {
                    yield this.addScript();
                    yield this.initOneSignal();
                    this.scriptinitalize = true;
                }
            }
            catch (_a) {
                this.scriptinitalize = false;
            }
        });
    }
    /**
     * @private
     * @return {?}
     */
    addScript() {
        return new Promise((/**
         * @param {?} resolve
         * @param {?} reject
         * @return {?}
         */
        (resolve, reject) => {
            /** @type {?} */
            const head = this.doc.getElementsByTagName('head')[0];
            /** @type {?} */
            const script = this.doc.createElement('script');
            script.type = 'text/javascript';
            script.onload = resolve;
            script.onerror = reject;
            script.src = this.scriptURL;
            head.appendChild(script);
        }));
    }
    /**
     * @private
     * @return {?}
     */
    initOneSignal() {
        return __awaiter(this, void 0, void 0, function* () {
            yield OneSignal.init(Object.assign({}, this.options));
            yield OneSignal.on('subscriptionChange', (/**
             * @param {?} isSubscribed
             * @return {?}
             */
            isSubscribed => {
                this.isSubscribe$.next(isSubscribed);
            }));
            // https://documentation.onesignal.com/docs/web-push-sdk#section-subscription-change
            this.isSupported$.next(yield OneSignal.isPushNotificationsSupported());
            this.isPushNotificationsEnabled$.next(yield OneSignal.isPushNotificationsEnabled());
            this.isOptedOut$.next(yield OneSignal.isOptedOut());
            this.isSubscribe$.next(yield Promise.all([
                OneSignal.isPushNotificationsEnabled(),
                OneSignal.isOptedOut(),
            ]).then((/**
             * @param {?} __0
             * @return {?}
             */
            ([hasSubscribe, hasOptedOut]) => hasSubscribe && !hasOptedOut)));
        });
    }
    /**
     * @private
     * @return {?}
     */
    listenForNotification() {
        OneSignal.on('notificationDisplay', (/**
         * @param {?} event
         * @return {?}
         */
        (event) => {
            console.log('OneSignal notification displayed:', event);
            this.event$.next(event);
            this.listenForNotification();
        }));
    }
}
OneSignalService.decorators = [
    { type: Injectable, args: [{
                providedIn: 'root',
            },] }
];
/** @nocollapse */
OneSignalService.ctorParameters = () => [
    { type: Document, decorators: [{ type: Inject, args: [DOCUMENT,] }] },
    { type: OneSignalOptions }
];
/** @nocollapse */ OneSignalService.ɵprov = ɵɵdefineInjectable({ factory: function OneSignalService_Factory() { return new OneSignalService(ɵɵinject(DOCUMENT), ɵɵinject(OneSignalOptions)); }, token: OneSignalService, providedIn: "root" });
__decorate([
    ExecIf('isInitialized'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], OneSignalService.prototype, "subscribe", null);
__decorate([
    ExecIf('isInitialized'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", []),
    __metadata("design:returntype", void 0)
], OneSignalService.prototype, "unsubscribe", null);
__decorate([
    ExecIf('isInitialized'),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [Array]),
    __metadata("design:returntype", void 0)
], OneSignalService.prototype, "push", null);
if (false) {
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.scriptinitalize;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.scriptURL;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.isSupported$;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.isSubscribe$;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.isOptedOut$;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.event$;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.isPushNotificationsEnabled$;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.doc;
    /**
     * @type {?}
     * @private
     */
    OneSignalService.prototype.options;
}

/**
 * @fileoverview added by tsickle
 * Generated from: lib/one-signal.module.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */
class NgxOneSignalModule {
    /**
     * @param {?=} options
     * @return {?}
     */
    static forRoot(options) {
        return {
            ngModule: NgxOneSignalModule,
            providers: [{ provide: OneSignalOptions, useValue: options }],
        };
    }
}
NgxOneSignalModule.decorators = [
    { type: NgModule }
];

/**
 * @fileoverview added by tsickle
 * Generated from: public_api.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

/**
 * @fileoverview added by tsickle
 * Generated from: ngx-onesignal.ts
 * @suppress {checkTypes,constantProperty,extraRequire,missingOverride,missingReturn,unusedPrivateMembers,uselessCode} checked by tsc
 */

export { NgxOneSignalModule, OneSignalOptions, OneSignalService, ExecIf as ɵa };
//# sourceMappingURL=ngx-onesignal.js.map
